==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridKeydownEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridKeydownEventArgsDetailDescriptionMetadata } from "./WebGridKeydownEventArgsDetailDescriptionMetadata";
import { WebGridKeydownEventArgsDescription } from "./WebGridKeydownEventArgsDescription";
/**
 * @hidden
 */
var WebGridKeydownEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridKeydownEventArgsDescriptionMetadata, _super);
    function WebGridKeydownEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridKeydownEventArgsDescriptionMetadata.b = function (a) {
        if (WebGridKeydownEventArgsDescriptionMetadata.a == null) {
            WebGridKeydownEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridKeydownEventArgsDescriptionMetadata.c(WebGridKeydownEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebGridKeydownEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridKeydownEventArgsDescriptionMetadata.a);
        WebGridKeydownEventArgsDetailDescriptionMetadata.d(a);
    };
    WebGridKeydownEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridKeydownEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebGridKeydownEventArgsDetail");
    };
    WebGridKeydownEventArgsDescriptionMetadata.d = function (a) {
        WebGridKeydownEventArgsDescriptionMetadata.b(a);
        a.aa("WebGridKeydownEventArgs", function () { return new WebGridKeydownEventArgsDescription(); });
        a.z("WebGridKeydownEventArgs", WebGridKeydownEventArgsDescriptionMetadata.a);
    };
    WebGridKeydownEventArgsDescriptionMetadata.$t = markType(WebGridKeydownEventArgsDescriptionMetadata, 'WebGridKeydownEventArgsDescriptionMetadata');
    WebGridKeydownEventArgsDescriptionMetadata.a = null;
    return WebGridKeydownEventArgsDescriptionMetadata;
}(Base));
export { WebGridKeydownEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridKeydownEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridKeydownEventArgsDetailDescriptionMetadata } from "./WebGridKeydownEventArgsDetailDescriptionMetadata";
import { WebGridKeydownEventArgsDescription } from "./WebGridKeydownEventArgsDescription";
/**
 * @hidden
 */
var WebGridKeydownEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridKeydownEventArgsDescriptionMetadata, _super);
    function WebGridKeydownEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridKeydownEventArgsDescriptionMetadata.b = function (a) {
        if (WebGridKeydownEventArgsDescriptionMetadata.a == null) {
            WebGridKeydownEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridKeydownEventArgsDescriptionMetadata.c(WebGridKeydownEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebGridKeydownEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridKeydownEventArgsDescriptionMetadata.a);
        WebGridKeydownEventArgsDetailDescriptionMetadata.d(a);
    };
    WebGridKeydownEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridKeydownEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebGridKeydownEventArgsDetail");
    };
    WebGridKeydownEventArgsDescriptionMetadata.d = function (a) {
        WebGridKeydownEventArgsDescriptionMetadata.b(a);
        a.ac("WebGridKeydownEventArgs", function () { return new WebGridKeydownEventArgsDescription(); });
        a.ab("WebGridKeydownEventArgs", WebGridKeydownEventArgsDescriptionMetadata.a);
    };
    WebGridKeydownEventArgsDescriptionMetadata.$t = markType(WebGridKeydownEventArgsDescriptionMetadata, 'WebGridKeydownEventArgsDescriptionMetadata');
    WebGridKeydownEventArgsDescriptionMetadata.a = null;
    return WebGridKeydownEventArgsDescriptionMetadata;
}(Base));
export { WebGridKeydownEventArgsDescriptionMetadata };
